package com.fs.live.mapper;


import com.fs.live.domain.LiveUserFollow;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 用户直播关注Mapper接口
 *
 * @author fs
 * @date 2025-07-11
 */
public interface LiveUserFollowMapper {
    /**
     * 查询用户直播关注
     *
     * @param id 用户直播关注主键
     * @return 用户直播关注
     */
    LiveUserFollow selectLiveUserFollowById(Long id);

    /**
     * 查询用户直播关注列表
     *
     * @param liveUserFollow 用户直播关注
     * @return 用户直播关注集合
     */
    List<LiveUserFollow> selectLiveUserFollowList(LiveUserFollow liveUserFollow);

    /**
     * 新增用户直播关注
     *
     * @param liveUserFollow 用户直播关注
     * @return 结果
     */
    int insertLiveUserFollow(LiveUserFollow liveUserFollow);

    /**
     * 修改用户直播关注
     *
     * @param liveUserFollow 用户直播关注
     * @return 结果
     */
    int updateLiveUserFollow(LiveUserFollow liveUserFollow);

    /**
     * 删除用户直播关注
     *
     * @param id 用户直播关注主键
     * @return 结果
     */
    int deleteLiveUserFollowById(Long id);

    /**
     * 批量删除用户直播关注
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteLiveUserFollowByIds(Long[] ids);

    LiveUserFollow selectLiveUserFollowByLiveIdAndUserId(@Param("liveId")Long liveId, @Param("userId")Long userId);

    void deleteLiveUserFollowByLiveIdAndUserId(@Param("liveId")Long liveId, @Param("userId")Long userId);
}
